@@ -122,6 +122,7 @@ class PartitionFetcher(object):
             self.messageReader.set_consumer_client(self.commitOffsetClient)
             self.messageReader.set_query_offset_client(self.queryPartitionClient)
             self.messageReader.set_outer_checkpoint(outerCheckPoint)
+            self.messageReader.init_consumer_metrics()
 
         self.logger.info("The PartitionFetcher for topic: " +
                          str(topicTalosResourceName.topicTalosResourceName)
@@ -298,6 +299,9 @@ class PartitionFetcher(object):
         self.release_partition()
         self.update_state(TASK_STATE.UNLOCKED)
 
+    def get_falcon_data(self):
+        return self.messageReader.get_consumer_metrics().to_json_data()
+
     def shutdown(self):
         # set UNLOCKING to stop read and wait fetcher gracefully quit
         self.update_state(TASK_STATE.UNLOCKING)
