@@ -2,7 +2,8 @@
 # Copyright 2020, Xiaomi.
 # All rights reserved.
 # Author: huyumei@xiaomi.com
-# 
+#
+
 
 import requests
 import traceback
@@ -21,8 +22,15 @@ class FalconWriter(object):
 
 	def push_falcon_data(self, falconData=None):
 		try:
+			logger.debug("falconUrl: " + self.falconUrl)
+			logger.debug("data: " + falconData)
 			resp = requests.post(self.falconUrl, json=falconData, headers=self.headers)
+			logger.debug("resp: " + str(resp))
 			if not resp.status_code == 200:
 				logger.error("Post data failed, StatusCode: " + str(resp.status_code))
 		except Exception as throwable:
 			logger.error("catch Exception: " + str(traceback.format_exc()))
+
+
+
+
